@@ -12,11 +12,11 @@
 #include "akonadi-calendar_tests_export.h"
 #include "itiphandler.h"
 #include <KCalendarCore/IncidenceBase>
-#include <kmime/kmime_message.h>
 #include <QObject>
+#include <kmime/kmime_message.h>
 
 struct UnitTestResult {
-    typedef QList<UnitTestResult> List;
+    using List = QList<UnitTestResult>;
     QString from;
     QStringList to;
     QStringList cc;
@@ -29,36 +29,47 @@ struct UnitTestResult {
     }
 };
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class Identity;
 }
 
 class KJob;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ITIPHandlerComponentFactory;
 
 class AKONADI_CALENDAR_TESTS_EXPORT MailClient : public QObject
 {
     Q_OBJECT
 public:
-    enum Result {
-        ResultSuccess,
-        ResultNoAttendees,
-        ResultReallyNoAttendees,
-        ResultErrorCreatingTransport,
-        ResultErrorFetchingTransport,
-        ResultQueueJobError
-    };
+    enum Result { ResultSuccess, ResultNoAttendees, ResultReallyNoAttendees, ResultErrorCreatingTransport, ResultErrorFetchingTransport, ResultQueueJobError };
 
     explicit MailClient(ITIPHandlerComponentFactory *factory, QObject *parent = nullptr);
     ~MailClient();
 
-    void mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, bool bccMe, const QString &attachment = QString(), const QString &mailTransport = QString());
+    void mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                       const KIdentityManagement::Identity &identity,
+                       bool bccMe,
+                       const QString &attachment = QString(),
+                       const QString &mailTransport = QString());
 
-    void mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &attachment = QString(), const QString &sub = QString(), const QString &mailTransport = QString());
+    void mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                       const KIdentityManagement::Identity &identity,
+                       const QString &from,
+                       bool bccMe,
+                       const QString &attachment = QString(),
+                       const QString &sub = QString(),
+                       const QString &mailTransport = QString());
 
-    void mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &recipients, const QString &attachment = QString(), const QString &mailTransport = QString());
+    void mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                const KIdentityManagement::Identity &identity,
+                const QString &from,
+                bool bccMe,
+                const QString &recipients,
+                const QString &attachment = QString(),
+                const QString &mailTransport = QString());
 
     /**
       Sends mail with specified from, to and subject field and body as text.
@@ -78,8 +89,17 @@ public:
       @param mailTransport defines the mail transport method. See here the
       kdepimlibs/mailtransport library.
     */
-    void send(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, const QString &to, const QString &cc, const QString &subject, const QString &body, bool hidden = false, bool bccMe = false,
-              const QString &attachment = QString(), const QString &mailTransport = QString());
+    void send(const KCalendarCore::IncidenceBase::Ptr &incidence,
+              const KIdentityManagement::Identity &identity,
+              const QString &from,
+              const QString &to,
+              const QString &cc,
+              const QString &subject,
+              const QString &body,
+              bool hidden = false,
+              bool bccMe = false,
+              const QString &attachment = QString(),
+              const QString &mailTransport = QString());
 
 private:
     void handleQueueJobFinished(KJob *job);
